package com.ruoyi.project.common.service;

import java.util.List;
import com.ruoyi.project.common.domain.TCommonfile;

/**
 * 通用附件Service接口
 * 
 * @author ruoyi
 * @date 2020-12-11
 */
public interface ITCommonfileService 
{
    /**
     * 查询通用附件
     * 
     * @param id 通用附件ID
     * @return 通用附件
     */
    public TCommonfile selectTCommonfileById(Long id);

    /**
     * 查询通用附件列表
     * 
     * @param tCommonfile 通用附件
     * @return 通用附件集合
     */
    public List<TCommonfile> selectTCommonfileList(TCommonfile tCommonfile);

    /**
     * 新增通用附件
     * 
     * @param tCommonfile 通用附件
     * @return 结果
     */
    public int insertTCommonfile(TCommonfile tCommonfile);

    /**
     * 修改通用附件
     * 
     * @param tCommonfile 通用附件
     * @return 结果
     */
    public int updateTCommonfile(TCommonfile tCommonfile);

    /**
     * 批量删除通用附件
     * 
     * @param ids 需要删除的通用附件ID
     * @return 结果
     */
    public int deleteTCommonfileByIds(Long[] ids);

    /**
     * 删除通用附件信息
     * 
     * @param id 通用附件ID
     * @return 结果
     */
    public int deleteTCommonfileById(Long id);

    List<TCommonfile> selectAllFileList(TCommonfile tCommonfile);
}
